@@ -1,6 +1,6 @@
 /* debug.c - Simple debugging "switch" */
 
-/* Written 1998 by Werner Almesberger, EPFL DI-ICA */
+/* Written 1998-2000 by Werner Almesberger, EPFL DI-ICA */
 
 
 #include <stdlib.h>
@@ -34,6 +34,7 @@ void fab_option(const char *name,const char *value)
 
 void fab_start(void (*port_notify)(int number,int up))
 {
+    sig_start_all(port_notify);
 }
 
 
